@@ -1,19 +1,24 @@
 
-context("get_stations_list")
-
 context("update_station_list")
 
-# Timeout options are reset on update_station_list() exit ----------------------
-test_that("Timeout options are reset on update_station_list() exit", {
-  skip_on_cran()
-  update_station_list()
-  expect_equal(options("timeout")[[1]], 60)
+test_that("If user selects no, database not updated", {
+  f <- file()
+  options(GSODR_connection = f)
+  ans <- "no"
+  write(ans, f)
+  expect_error(update_station_list())
+  options(GSODR_connection = stdin())
+  close(f)
 })
 
-# update_forecast_locations() downloads and imports the proper file ------------
+# update_forecast_locations() d-loads, imports file and resets timeout on exit--
 test_that("update_station_list() downloads and imports proper file", {
   skip_on_cran()
-  update_station_list()
+  f <- file()
+  options(GSODR_connection = f)
+  ans <- "yes"
+  write(ans, f)
+  expect_message(update_station_list())
   load(system.file("extdata", "isd_history.rda", package = "GSODR"))
   expect_equal(ncol(isd_history), 13)
   expect_named(
@@ -34,4 +39,7 @@ test_that("update_station_list() downloads and imports proper file", {
       "ELEV_M_SRTM_90m"
     )
   )
+  expect_equal(options("timeout")[[1]], 60)
+  options(GSODR_connection = stdin())
+  close(f)
 })
